@@ -49,10 +49,13 @@ class MIME:
 class GlobalData:
     """
     Data global to whole task list. Should be passed to all templates.
+
+    - tasks: List of `Task.message` that are to be done.
     """
     title: str
     insecure: bool
     static: str  # URL
+    tasks: [str] = field(default_factory=list)
 
 
 @dataclass(frozen=True)
@@ -200,7 +203,7 @@ class TaskThumbnails(Task):
 
 class TaskTracks(Task):
     def __init__(self):
-        super().__init__('Thumbnails', mime_types=[
+        super().__init__('Tracks', mime_types=[
             'application/gpx+xml'
         ])
 
@@ -366,6 +369,7 @@ def __main__():
         title=args.title or args.basedir.resolve().name,
         insecure=args.insecure,
         static=args.static_location,
+        tasks=[t.message for t in TASKS if t.todo],
     )
 
     # Jinja2
